==> pulp_cli_console-0.1.1.dev0-py3-none-any.whl: pulpcore/cli/console/vulnerability.py <==
from typing import IO

import click
from pulp_glue.common.context import PulpContext, PulpEntityContext
from pulp_glue.console.context import PulpVulnerabilityReportContext

from pulpcore.cli.common.generic import (
    PulpCLIContext,
    chunk_size_option,
    href_option,
    list_command,
    pass_entity_context,
    pass_pulp_context,
    show_command,
)


def attach_vulnerability_commands(console_group: click.Group) -> None:
    @console_group.group()
    @pass_pulp_context
    @click.pass_context
    def vulnerability(ctx: click.Context, pulp_ctx: PulpContext, /) -> None:
        """Manage vulnerability reports."""
        ctx.obj = PulpVulnerabilityReportContext(pulp_ctx)

    lookup_options = [href_option]

    @vulnerability.command()
    @click.option(
        "--file", type=click.File("rb"), required=True, help="JSON file containing npm packages"
    )
    @chunk_size_option
    @pass_entity_context
    @pass_pulp_context
    def upload(
        pulp_ctx: PulpCLIContext,
        vulnerability_ctx: PulpEntityContext,
        /,
        file: IO[bytes],
        chunk_size: int,
    ) -> None:
        """Upload a vulnerability report JSON file."""
        assert isinstance(vulnerability_ctx, PulpVulnerabilityReportContext)
        result = vulnerability_ctx.upload(file, chunk_size)
        pulp_ctx.output_result(result)

    # Add commands to the vulnerability group
    vulnerability.add_command(list_command())
    vulnerability.add_command(show_command(decorators=lookup_options))
    vulnerability.add_command(upload)

==> pulp_cli_console-0.1.2.dev0-py3-none-any.whl: pulpcore/cli/console/vulnerability.py <==
from typing import IO

import click
from pulp_glue.common.context import PulpContext, PulpEntityContext
from pulp_glue.console.context import PulpVulnerabilityReportContext

from pulpcore.cli.common.generic import (
    PulpCLIContext,
    chunk_size_option,
    href_option,
    list_command,
    pass_entity_context,
    pass_pulp_context,
    show_command,
)


def attach_vulnerability_commands(console_group: click.Group) -> None:
    @console_group.group()
    @pass_pulp_context
    @click.pass_context
    def vulnerability(ctx: click.Context, pulp_ctx: PulpContext, /) -> None:
        """Manage vulnerability reports."""
        ctx.obj = PulpVulnerabilityReportContext(pulp_ctx)

    lookup_options = [href_option]

    @vulnerability.command()
    @click.option(
        "--file", type=click.File("rb"), required=True, help="JSON file containing npm packages"
    )
    @chunk_size_option
    @pass_entity_context
    @pass_pulp_context
    def create(
        pulp_ctx: PulpCLIContext,
        vulnerability_ctx: PulpEntityContext,
        /,
        file: IO[bytes],
        chunk_size: int,
    ) -> None:
        """Create a vulnerability report JSON file."""
        assert isinstance(vulnerability_ctx, PulpVulnerabilityReportContext)
        result = vulnerability_ctx.create_report(file, chunk_size)
        pulp_ctx.output_result(result)

    # Add commands to the vulnerability group
    vulnerability.add_command(list_command())
    vulnerability.add_command(show_command(decorators=lookup_options))
    vulnerability.add_command(create)
